.. _api:

API Reference
=============


Einsum Nodes
------------

.. automodule:: feinsum.einsum

Routines for empirical evaluation
---------------------------------

.. automodule:: feinsum.measure

Helpers to build :class:`feinsum.einsum.BatchedEinsum`
------------------------------------------------------

.. automodule:: feinsum.make_einsum

Interacting with code-transformation databases
----------------------------------------------

.. automodule:: feinsum.sql_utils

Some helper :mod:`loopy` transformations relevant for Einstein Summations
-------------------------------------------------------------------------

.. automodule:: feinsum.loopy_utils

Lowering to :mod:`loopy`
------------------------

.. automodule:: feinsum.codegen.loopy


Canonicalization
----------------

.. automodule:: feinsum.canonicalization

Miscellaneous Utilities
-----------------------

.. automodule:: feinsum.utils
.. automodule:: feinsum.typing
.. automodule:: feinsum.cl_utils


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
